projectal.dynamic_enums API documentation

# projectal.dynamic_enums

Implementations of all Projectal dynamic enums.

All classes here inherit from `projectal.dynamic_enum.DynamicEnum`.

View Source

     1"""
     2Implementations of all Projectal dynamic enums.
     3
     4All classes here inherit from `projectal.dynamic_enum.DynamicEnum`.
     5"""
     6from projectal.dynamic_enums.company_types import CompanyTypes
     7from projectal.dynamic_enums.skill_levels import SkillLevels
     8from projectal.dynamic_enums.staff_types import StaffTypes
     9from projectal.dynamic_enums.priority_levels import PriorityLevels
    10from projectal.dynamic_enums.complexity_levels import ComplexityLevels
    11from projectal.dynamic_enums.currency_list import CurrencyList